TierTheme class
Constructors
-
TierTheme({Color? primaryTextColor, StatusBarType? statusBarType, List<
BackgroundColor> ? backgroundColors})
Properties
-
backgroundColorList
→ List<
Color> -
no setter
-
backgroundColors
↔ List<
BackgroundColor> ? -
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- primaryTextColor ↔ Color?
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- statusBarType ↔ StatusBarType?
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited